import sys
import logging.config
from box.argparse import Program
from .command import Command
from .create import create
from .settings import settings

class Program(Program):
    
    #Public
     
    def __call__(self):
        self._config()
        self._execute()
         
    #Protected
    
    _command_class = Command
    
    def _config(self):
        logging.config.dictConfig(settings.logging)        
        logger = logging.getLogger()
        if self._command.debug:
            logger.setLevel(logging.DEBUG)
        if self._command.verbose:
            logger.setLevel(logging.INFO)
        if self._command.quiet:
            logger.setLevel(logging.ERROR)      
    
    def _execute(self):
        try:
            create(self._command.path, 
                pattern=self._command.pattern,
                command=self._command.command)
        except Exception as exception:
            logging.getLogger(__name__).error(
                self._format_exception(exception), 
                exc_info=self._command.debug)
            sys.exit(1)
    
    def _format_exception(self, exception):
        return '{category}: {message}'.format(
            category=type(exception).__name__,
            message=str(exception))
    
        
program = Program(sys.argv)