import os
from box import Settings
from .version import version

class Settings(Settings):
    
    #Main
    
    default_command = 'run bootstrap'
    default_pattern = 'default'
    
    #Console
    
    @property
    def argparse(self):
        return {
            'prog': 'packgram',
            'add_help': False,            
            'arguments': [
                {
                 'name': 'path',
                 'help': 'Path to create packgram.',
                },
                {
                 'dest': 'command',
                 'flags': ['-c', '--command'],
                 'default': self.default_command,
                 'help': 'Command to bootstrap packgram.',                 
                },                            
                {
                 'dest': 'debug',
                 'action': 'store_true',
                 'flags': ['-d', '--debug'],
                 'help': 'Enable debug mode.',
                },
                {
                 'action': 'help',
                 'flags': ['-h', '--help'],
                 'help': 'Display this help message.',                         
                },
                {
                 'dest': 'quiet',
                 'action': 'store_true',
                 'flags': ['-q', '--quiet'],
                 'help': 'Enable quiet mode.',
                }, 
                {
                 'dest': 'pattern',
                 'flags': ['-p', '--pattern'],
                 'default': self.default_pattern,
                 'help': 'Pattern to create packgram.',                 
                },                                                   
                {
                 'dest': 'verbose',
                 'action': 'store_true',
                 'flags': ['-v', '--verbose'],
                 'help': 'Enable verbose mode.',                 
                },                                                                                                                           
                {
                 'action': 'version',
                 'flags': ['-V', '--version'],
                 'version': 'Run '+str(version),
                 'help': 'Display the program version.',                          
                },                                                             
            ],        
        }
    
    #Logging
    
    default_logging_level = 'WARNING'    
   
    @property
    def logging(self):
        return {
            'version': 1,
            'disable_existing_loggers': False,
            'loggers': {
                '': {
                    'handlers': ['default'],        
                    'level': self.default_logging_level,
                    'propagate': True,
                },                                                                 
            },
            'handlers': {
                'default': {
                    'level':'DEBUG',    
                    'class':'logging.StreamHandler',
                    'formatter': 'default',
                },                                                   
            },
            'formatters': {
                'default': {
                    'format': '[%(levelname)s] %(message)s'
                },                                                
            },
        }
        
    #Extensions
    
    _extensions = [
        os.path.join(os.path.expanduser('~'), '.packgram', 'settings.py'),
    ]
    
    
settings = Settings()